import{d as v,ex as w,ey as k,r as m,b as a,c as s,bw as i,ez as _,er as p,eA as b,ew as f,e as h,I as g,eu as c,u as x,eq as I,bu as C,t as D}from"./registerWidgets.92d2f644.js";import{b as S}from"./icons.f7e2c66d.js";import{T as B}from"./Tooltip.56ae9c4a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="fd83005e-34fd-496b-8783-97e3dab7a957",t._sentryDebugIdIdentifier="sentry-dbid-fd83005e-34fd-496b-8783-97e3dab7a957")}catch{}})();const T={class:"sidebar"},N={class:"section-name"},O=["onClick"],E={class:"item-name"},V={key:0,class:"tag soon"},z={key:1,class:"tag beta"},A={key:2,class:"tag cloud"},L=v({__name:"Sidebar",props:{sections:{}},setup(t){var u;const o=w(),l=k(),d=m((u=l.name)!=null?u:"forms"),y=n=>{n.unavailable||(o.push(n.path),d.value=n.path)};return(n,R)=>(a(),s("div",T,[(a(!0),s(i,null,_(n.sections,r=>(a(),s("div",{key:r.name,class:"section"},[p("span",N,b(r.name),1),(a(!0),s(i,null,_(r.items,e=>(a(),s("div",{key:e.name,role:"button",class:f(["item",{active:d.value===e.path,disabled:e.unavailable||r.cloud}]),tabindex:"0",onClick:q=>y(e)},[h(g,{class:f(["icon",{disabled:e.unavailable,active:d.value===e.path}]),path:e.icon,width:"20",height:"20"},null,8,["class","path"]),p("span",E,b(e.name),1),e.unavailable?(a(),s("span",V,"SOON")):c("",!0),e.beta?(a(),s("span",z,"BETA")):c("",!0),e.cloud?(a(),s("span",A,"CLOUD")):c("",!0),e.warning?(a(),x(B,{key:3,class:"warning",text:e.warning,fixed:!0,top:18,left:18},{default:I(()=>[h(g,{path:C(S),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):c("",!0)],10,O))),128))]))),128))]))}});const j=D(L,[["__scopeId","data-v-16ccb6d0"]]);export{j as S};
//# sourceMappingURL=Sidebar.03e52ede.js.map
