import{d,F as p,b as n,c as a,er as o,bw as l,ez as r,ew as _,eA as i,eu as u,t as f}from"./registerWidgets.92d2f644.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="18b77e56-21ad-4119-af86-dbd35cdecd4b",e._sentryDebugIdIdentifier="sentry-dbid-18b77e56-21ad-4119-af86-dbd35cdecd4b")}catch{}})();const b={key:0,class:"p-steps p-component"},m={class:"p-steps-list"},y={class:"p-menuitem-link"},g={class:"p-steps-number"},I=d({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,c=p(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,w)=>e.stepsInfo?(n(),a("nav",b,[o("ol",m,[(n(!0),a(l,null,r(c.value,(k,t)=>(n(),a("li",{key:t,class:_(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[o("span",y,[o("span",g,i(t+1),1)])],2))),128))])])):u("",!0)}});const D=f(I,[["__scopeId","data-v-c6d9488a"]]);export{D as S};
//# sourceMappingURL=Steps.b001c6e8.js.map
