import{t as n,b as o,c as a,er as r,d as _,a as d,u as i,eq as l,e as f,bh as u}from"./registerWidgets.92d2f644.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7832e2bf-6d93-41f7-a89c-d7be063085b7",e._sentryDebugIdIdentifier="sentry-dbid-7832e2bf-6d93-41f7-a89c-d7be063085b7")}catch{}})();const p={},b={width:"12",height:"10",viewBox:"0 0 12 10",fill:"none",xmlns:"http://www.w3.org/2000/svg"},h=r("path",{d:"M2.8725 4.25L5.5575 1.5575L4.5 0.5L0 5L4.5 9.5L5.5575 8.4425L2.8725 5.75H12V4.25H2.8725Z",fill:"#6D7C93"},null,-1),k=[h];function w(e,t){return o(),a("svg",b,k)}const B=n(p,[["render",w]]),g=_({__name:"BackButton",props:{link:{}},setup(e){return(t,s)=>{const c=d("router-link");return o(),i(c,{class:"link-button",to:t.link},{default:l(()=>[f(B),u(" Back ")]),_:1},8,["to"])}}});const m=n(g,[["__scopeId","data-v-56a12edc"]]);export{m as B};
//# sourceMappingURL=BackButton.47b3a926.js.map
