import{_ as k}from"./logo.084e5d7c.js";import{t as i,b as o,c as t,eB as u,eC as p,er as a,d as b,ex as I,a as $,bu as _,eA as g,e as r,eq as m,bh as f,bw as w,ez as x,eu as L,eZ as C}from"./registerWidgets.92d2f644.js";import{p as l}from"./passwordlessManager.d1484834.js";import{a as N}from"./asyncComputed.969e5e52.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="8a3717ca-9e72-4d7b-bc1e-0f1c32b9d2c8",e._sentryDebugIdIdentifier="sentry-dbid-8a3717ca-9e72-4d7b-bc1e-0f1c32b9d2c8")}catch{}})();const B={},h=e=>(u("data-v-439be421"),e=e(),p(),e),D={class:"logo"},S=h(()=>a("img",{class:"logo-img",src:k,alt:"Abstra cloud logo"},null,-1)),V=h(()=>a("span",null,"Abstra Cloud",-1)),A=[S,V];function E(e,s){return o(),t("div",D,A)}const R=i(B,[["render",E],["__scopeId","data-v-439be421"]]),U={key:0},q={key:1,class:"logged"},z={class:"author-email"},F={key:2},M=b({__name:"LoginBlock",setup(e){const s=I(),{result:c,loading:n,refetch:d}=N(async()=>l.getUser());function v(){l.removeUser(),d(),s.push({name:"login"})}return(P,Q)=>{const y=$("router-link");return _(n)?(o(),t("div",U,"loading...")):_(c)?(o(),t("div",q,[a("span",z,g(_(c).claims.email),1),a("button",{class:"btn",onClick:v},"Logout")])):(o(),t("div",F,[r(y,{class:"btn",to:"/login"},{default:m(()=>[f("Login")]),_:1})]))}}});const T=i(M,[["__scopeId","data-v-6c08207b"]]),Z=e=>(u("data-v-7bfa390c"),e=e(),p(),e),j={class:"nav"},G={class:"left"},H={key:0,class:"breadcrumb-container"},J=Z(()=>a("span",{class:"divider"},">",-1)),K={class:"right"},O=b({__name:"Navbar",props:{breadcrumb:{}},setup(e){return(s,c)=>(o(),t("nav",j,[a("div",G,[r(R),s.breadcrumb?(o(),t("div",H,[(o(!0),t(w,null,x(s.breadcrumb,(n,d)=>(o(),t("span",{key:d,class:"breadcrumb-item"},[r(_(C),{class:"breadcrumb-link",to:n.path},{default:m(()=>[f(g(n.label),1)]),_:2},1032,["to"]),J]))),128))])):L("",!0)]),a("div",K,[r(T)])]))}});const se=i(O,[["__scopeId","data-v-7bfa390c"]]);export{se as N};
//# sourceMappingURL=Navbar.807fddfe.js.map
