import{S as c}from"./Sidebar.03e52ede.js";import{N as m}from"./Navbar.807fddfe.js";import{C as d,D as p,E as l}from"./icons.f7e2c66d.js";import{d as u,ey as _,F as b,a as g,b as f,c as v,e as t,er as y,bw as z,t as w}from"./registerWidgets.92d2f644.js";import{a as h}from"./asyncComputed.969e5e52.js";import"./gateway.b5fd6e0f.js";import{O as I}from"./organization.677061f5.js";import"./index.a8106eac.js";import"./Tooltip.56ae9c4a.js";import"./logo.084e5d7c.js";import"./passwordlessManager.d1484834.js";import"./pubsub.cabffe13.js";import"./storage.63ab52ef.js";import"./activeRecord.1a640186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7d55d4ae-0549-4595-a090-38e48c611587",e._sentryDebugIdIdentifier="sentry-dbid-7d55d4ae-0549-4595-a090-38e48c611587")}catch{}})();const O={class:"organization"},D=u({__name:"Organization",setup(e){const n=_().params.organizationId,{result:o}=h(()=>I.get(n)),r=b(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(k,x)=>{const s=g("router-view");return f(),v(z,null,[t(m,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const G=w(D,[["__scopeId","data-v-51ce7239"]]);export{G as default};
//# sourceMappingURL=Organization.f80afb65.js.map
