.logo[data-v-439be421]{display:flex;align-items:center}.logo .logo-img[data-v-439be421]{height:50px}.logo span[data-v-439be421]{font-size:18px;font-weight:600;margin-left:10px}[data-v-6c08207b]:root{--main-font-family: DM Sans, sans-serif}[data-v-6c08207b]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-6c08207b]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-6c08207b]{background-color:#fff;padding:10px}.logged[data-v-6c08207b]{display:flex;align-items:center;gap:10px}.btn[data-v-6c08207b]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026}.btn[data-v-6c08207b]:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.btn[data-v-6c08207b]:active,.btn active[data-v-6c08207b]{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}[data-v-7bfa390c]:root{--main-font-family: DM Sans, sans-serif}[data-v-7bfa390c]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-7bfa390c]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-7bfa390c]{background-color:#fff;padding:10px}.nav[data-v-7bfa390c]{display:flex;align-items:center;justify-content:space-between;box-shadow:0 0 100px #00000005;box-sizing:border-box;width:100%;height:48px;padding:0 16px;gap:20px}.nav .left[data-v-7bfa390c]{display:flex;gap:20px}.nav .left .breadcrumb-container[data-v-7bfa390c]{display:flex;align-items:center;color:#414a58}@media screen and (max-width: 800px){.nav .left .breadcrumb-container[data-v-7bfa390c]{display:none}}.nav .left .breadcrumb-container .breadcrumb-item .breadcrumb-link[data-v-7bfa390c]{text-decoration:none;color:#272d35;font-weight:400;font-size:16px}.nav .left .breadcrumb-container .breadcrumb-item .breadcrumb-link[data-v-7bfa390c]:hover{cursor:pointer;text-decoration:underline}.nav .left .breadcrumb-container .breadcrumb-item:last-child .divider[data-v-7bfa390c]{display:none}.nav .left .breadcrumb-container .divider[data-v-7bfa390c]{margin:0 8px}
