import{u as s}from"./icons.f7e2c66d.js";import{d as r,a as c,b as f,c as i,e as d,bu as _,bh as l,t as u}from"./registerWidgets.92d2f644.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="12e04af0-bbff-4e87-a738-c33f221f3f8d",e._sentryDebugIdIdentifier="sentry-dbid-12e04af0-bbff-4e87-a738-c33f221f3f8d")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return f(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[d(a,{class:"icon",path:_(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.1708a07b.js.map
