import{t as r,a,b as i,u as c,f as p,g as d,_,h as u,k as l,T as f,P as h,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.92d2f644.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="95f7f119-0226-4c40-9b48-aa00b851e4d7",e._sentryDebugIdIdentifier="sentry-dbid-95f7f119-0226-4c40-9b48-aa00b851e4d7")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.d09cfac6.js"),["assets/Player.d09cfac6.js","assets/index.75f517f3.js","assets/registerWidgets.92d2f644.js","assets/registerWidgets.79d84882.css","assets/uuid.cd57cf20.js","assets/broker.dd00d469.js","assets/passwordlessManager.d1484834.js","assets/pubsub.cabffe13.js","assets/storage.63ab52ef.js","assets/Passwordless.493e6d57.js","assets/CircularLoading.e3659467.js","assets/lottie.8475a642.js","assets/CircularLoading.f81b57b4.css","assets/icons.f7e2c66d.js","assets/Passwordless.86ac0c56.css","assets/executeJs.3da04476.js","assets/PlayerNavbar.e2f19917.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.b001c6e8.js","assets/Steps.998aa76d.css","assets/Modal.2ef1e90a.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.c49cae71.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.0b91cf80.js","assets/broker.95c7aa9a.css","assets/DashPlayer.766f9779.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.969e5e52.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});f.init(),D.init(),e.use(o),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.e18252bc.js.map
