import{M as a}from"./Modal.2ef1e90a.js";import{d as r,E as d,r as _,a as c,b as l,c as i,e as n,eq as f,bw as m,er as u,t as p}from"./registerWidgets.92d2f644.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="77960869-b1b2-4e5a-a295-a0e7e25d3425",e._sentryDebugIdIdentifier="sentry-dbid-77960869-b1b2-4e5a-a295-a0e7e25d3425")}catch{}})();const b=["src"],y=r({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=_(null);return(g,w)=>{const s=c("router-view");return l(),i(m,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:f(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const x=p(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.46776dce.js.map
