import{D as d,F as t}from"./registerWidgets.92d2f644.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="fd3e3955-f2cc-48c7-9cc4-ee6d2432b0c3",r._sentryDebugIdIdentifier="sentry-dbid-fd3e3955-f2cc-48c7-9cc4-ee6d2432b0c3")}catch{}})();const i=r=>{const e=d({loading:!0,result:null,error:null}),n=l=>(e.value={loading:!1,result:l,error:null},l),s=l=>{e.value={loading:!1,result:null,error:l}},o=()=>{e.value={loading:!0,result:null,error:null},r().then(n).catch(s)};o();const u=t(()=>e.value.loading),c=t(()=>e.value.result),a=t(()=>e.value.error);return{loading:u,result:c,error:a,refetch:o}};export{i as a};
//# sourceMappingURL=asyncComputed.969e5e52.js.map
