[data-v-acd019f3]:root{--main-font-family: DM Sans, sans-serif}[data-v-acd019f3]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-acd019f3]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-acd019f3]{background-color:#fff;padding:10px}.empty-list[data-v-acd019f3]{display:flex;flex-direction:column;justify-content:center;align-items:center;padding:4rem;background-color:#fff;border-radius:.5rem;color:#8692a5;gap:10px}.empty-list .empty-list-title h1[data-v-acd019f3]{font-size:18px;line-height:24px;font-weight:500;color:#4e596a}.empty-list .empty-list-description[data-v-acd019f3]{font-size:.75rem;display:flex;flex-direction:column;gap:10px;text-align:center;margin-bottom:2rem}.empty-list .empty-list-description p[data-v-acd019f3]{margin:0}.empty-list .empty-list-description p a[data-v-acd019f3]{cursor:pointer;text-decoration:underline;color:#3d79d8}.empty-list button[data-v-acd019f3]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026;margin:auto}.empty-list button[data-v-acd019f3]:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.empty-list button[data-v-acd019f3]:active,.empty-list button active[data-v-acd019f3]{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}.runtimes-container[data-v-acd019f3]{display:flex;flex-direction:column;width:100%;gap:2rem}.runtimes-container h1[data-v-acd019f3]{font-size:1.5rem;grid-area:title;margin:0;color:#5a677a}.runtimes-container .header[data-v-acd019f3]{display:flex;justify-content:space-between;align-items:center;gap:60px;margin-bottom:26px}.runtimes-container .header .title-wrapper p[data-v-acd019f3]{font-weight:400;font-size:12px;line-height:16px;color:#6d7c93}.runtimes-container .header button[data-v-acd019f3]{grid-area:button;cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026}.runtimes-container .header button[data-v-acd019f3]:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.runtimes-container .header button[data-v-acd019f3]:active,.runtimes-container .header button active[data-v-acd019f3]{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}.runtimes-container table[data-v-acd019f3]{border-radius:8px;width:100%;box-shadow:0 4px 8px #0000000d}.runtimes-container table thead[data-v-acd019f3]{display:grid;grid-template-columns:1fr 1.2fr 1fr;font-weight:500;font-size:.6rem;background-color:#fff;border-bottom:1px solid #edeff2}.runtimes-container table thead td[data-v-acd019f3]{color:#6d7c93;text-transform:uppercase;display:flex;align-items:center;justify-content:flex-start;padding:16px 0;box-sizing:border-box}.runtimes-container table thead td[data-v-acd019f3]:first-child,.runtimes-container table thead td[data-v-acd019f3]:last-child{justify-content:center}.runtimes-container .video-section[data-v-acd019f3]{display:flex;flex-direction:column;align-items:flex-start;gap:20px}.runtimes-container .video-section .runtimes-example-video[data-v-acd019f3]{align-self:center;border-radius:5px;width:640px;aspect-ratio:16/9;max-width:100%}tr[data-v-acd019f3]{display:grid;grid-template-columns:1fr 1.2fr 1fr}tr td[data-v-acd019f3]{font-weight:400;font-size:.625rem;line-height:12px;color:#4e596a;display:flex;align-items:center;justify-content:flex-start;width:100%;padding:20px 0;border-bottom:1px solid #f3f4f6;gap:5px}tr td.title[data-v-acd019f3]{overflow:hidden;text-overflow:ellipsis}tr td.centered[data-v-acd019f3]{justify-content:center}.loading-wrapper[data-v-acd019f3]{width:100%;height:100%;display:flex;justify-content:center;align-items:center}.cta[data-v-acd019f3]{height:32px;box-sizing:border-box;display:flex;align-items:center;justify-content:center}
