import{d as u,ey as b,F as p,a as g,b as _,c as v,e as r,er as l,bw as f,t as y}from"./registerWidgets.92d2f644.js";import{a as h}from"./asyncComputed.969e5e52.js";import{P as j}from"./project.76f68b3e.js";import"./gateway.b5fd6e0f.js";import{O as z}from"./organization.677061f5.js";import"./index.a8106eac.js";import{N as I}from"./Navbar.807fddfe.js";import{S as w}from"./Sidebar.03e52ede.js";import{F as P,G as k,H as x,I as B,J as C,K as D,L as $,C as E,D as M,E as N}from"./icons.f7e2c66d.js";import"./activeRecord.1a640186.js";import"./pubsub.cabffe13.js";import"./passwordlessManager.d1484834.js";import"./storage.63ab52ef.js";import"./logo.084e5d7c.js";import"./Tooltip.56ae9c4a.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[s]="4be1eba5-d633-49bf-bbeb-e1473a0d09cb",o._sentryDebugIdIdentifier="sentry-dbid-4be1eba5-d633-49bf-bbeb-e1473a0d09cb")}catch{}})();const S={class:"project"},F={class:"content-wrapper"},L=u({__name:"Project",setup(o){const i=b().params.projectId,{result:e}=h(()=>j.get(i).then(async a=>{const t=await z.get(a.organizationId);return{project:a,organization:t}})),d=p(()=>{var a,t,n,c;return((a=e.value)==null?void 0:a.organization)&&e.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=e.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(c=e.value)==null?void 0:c.organization.id}`},{label:e.value.project.name,path:`/projects/${e.value.project.id}`}]:void 0}),m=p(()=>{var a;return(a=e.value)!=null&&a.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:P},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:x},{name:"API Keys",path:"api-keys",icon:B},{name:"Env Vars",path:"env-vars",icon:C},{name:"Logs",icon:D,path:"logs",beta:!0},{name:"Settings",icon:$,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:E,path:`/organizations/${e.value.project.organizationId}/projects`},{name:"Members",icon:M,path:`/organizations/${e.value.project.organizationId}/members`},{name:"Billing",icon:N,path:`/organizations/${e.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(a,t)=>{const n=g("router-view");return _(),v(f,null,[r(I,{class:"nav",breadcrumb:d.value},null,8,["breadcrumb"]),l("div",S,[r(w,{class:"sidebar",sections:m.value},null,8,["sections"]),l("div",F,[r(n)])])],64)}}});const Z=y(L,[["__scopeId","data-v-d311093f"]]);export{Z as default};
//# sourceMappingURL=Project.985d4b6b.js.map
