import{d as b,ex as y,F as _,b as g,u as J,bu as h}from"./registerWidgets.92d2f644.js";import{e as k,f as w,g as C}from"./icons.f7e2c66d.js";import{a as x}from"./asyncComputed.969e5e52.js";import{J as l}from"./jobs.d086d8ab.js";import{R as I}from"./RuntimeList.72cb38fa.js";import"./activeRecord.1a640186.js";import"./pubsub.cabffe13.js";import"./DropdownMenu.737d17d7.js";import"./CircularLoading.e3659467.js";import"./lottie.8475a642.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[i]="081859ed-8cfd-4de8-8f10-1d1f35409a8c",n._sentryDebugIdIdentifier="sentry-dbid-081859ed-8cfd-4de8-8f10-1d1f35409a8c")}catch{}})();const $=b({__name:"Jobs",setup(n){const i=y(),{loading:r,result:a,refetch:d}=x(()=>l.list()),c=({key:e})=>i.push({path:`/_editor/job/${encodeURIComponent(e)}`}),u=async({key:e})=>{var o,t;await((t=(o=a.value)==null?void 0:o.find(s=>s.identifier===e))==null?void 0:t.duplicate()),d()},f=async()=>{const e=await l.create();c({key:e.identifier})},p=async({key:e})=>{var o,t;confirm("Are you sure you want to delete this job?")&&(await((t=(o=a.value)==null?void 0:o.find(s=>s.identifier===e))==null?void 0:t.delete()),d())},m=_(()=>{var e,o;return{columns:[{name:"Job Name"},{name:"Path"},{name:"Job Actions"}],rows:(o=(e=a.value)==null?void 0:e.map(t=>({key:t.identifier,cells:[{text:t.title,classes:["title","centered"],link:`/_editor/job/${encodeURIComponent(t.identifier)}`},{text:t.identifier},{text:"",classes:["centered"],actions:[{icon:k,label:"Delete",onClick:p,dangerous:!0},{icon:w,label:"Edit Job",onClick:c},{icon:C,label:"Duplicate",onClick:u}]}]})))!=null?o:[]}});return(e,o)=>(g(),J(I,{loading:h(r),title:"Python Jobs",description:"Schedule Python scripts like events on a calendar","create-button-text":"Create Job","empty-title":"No jobs here yet",table:m.value,onCreate:f},null,8,["loading","table"]))}});export{$ as default};
//# sourceMappingURL=Jobs.c9ed323d.js.map
