import{r as a}from"./icons.f7e2c66d.js";import{d as c,ey as u,ex as i,a as p,b as _,c as l,e as f,bu as b,bh as m,t as y}from"./registerWidgets.92d2f644.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="86d444e3-0ae1-4bde-a7d7-44c41fdd8d10",e._sentryDebugIdIdentifier="sentry-dbid-86d444e3-0ae1-4bde-a7d7-44c41fdd8d10")}catch{}})();const v=c({__name:"PreviewButton",props:{model:{}},setup(e){const t=e,o=u(),s=i(),d=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const r=p("icon");return _(),l("button",{class:"preview-button",onClick:d},[f(r,{class:"icon",path:b(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),m(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.1ee64333.js.map
